# Slot: description


a description of the element's purpose and use

URI: [http://w3id.org/biolink/biolinkml/meta/schema_definition_description](slot_uri)
## Domain and Range

[SchemaDefinition](SchemaDefinition.md) -><sub>opt</sub> [String](String.md)
## Inheritance

 *  is_a: [description](description.md) *subsets*: (owl)
## Children

## Used by

 * [SchemaDefinition](SchemaDefinition.md)
